@@ -13,8 +13,8 @@ class TurboFlot(Widget):
         A TurboGears Flot Widget.
     """
     template = """
-      <div xmlns:py="http://purl.org/kid/ns#" id="${id}" 
-           style="width:${width};height:${height};">
+      <div xmlns:py="http://purl.org/kid/ns#">
+        <div style="width:${width};height:${height};" id="${id}" />
         <script>
           $(document).ready(function() {
             $.plot($("#${id}"), ${data}, ${options});
